@@ -1,7 +1,7 @@
 # ABSTRACT: Subroutines for making simple command line scripts
 package CLI::Helpers;
 
-our $VERSION = 0.8;
+our $VERSION = 0.9;
 our $_OPTIONS_PARSED;
 
 use strict;
@@ -11,7 +11,7 @@ use File::Basename;
 use Getopt::Long qw(:config pass_through);
 use IPC::Run3;
 use Sys::Syslog qw(:standard);
-use Term::ANSIColor qw(color colored colorstrip);
+use Term::ANSIColor 2.01 qw(color colored colorstrip);
 use Term::ReadLine;
 use YAML;
 
@@ -407,7 +407,7 @@ CLI::Helpers - Subroutines for making simple command line scripts
 
 =head1 VERSION
 
-version 0.8
+version 0.9
 
 =head1 SYNOPSIS
 
